@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; c-indent-level: 8 -*- */
 /*
  * Copyright (C) 2005, Nickolay V. Shmyrev <nshmyrev@yandex.ru>
  *
@@ -25,6 +24,7 @@
 #include "djvu-links.h"
 #include "djvu-document-private.h"
 #include "ev-file-exporter.h"
+#include "ev-document-info.h"
 #include "ev-document-misc.h"
 #include "ev-document-find.h"
 #include "ev-document-links.h"
@@ -522,6 +522,31 @@ djvu_document_get_thumbnail_surface (EvDocument      *document,
 	return surface;
 }
 
+static EvDocumentInfo *
+djvu_document_get_info (EvDocument *document)
+{
+        DjvuDocument *djvu_document = DJVU_DOCUMENT (document);
+        const char *xmp;
+        miniexp_t anno;
+        EvDocumentInfo *info;
+
+        info = ev_document_info_new ();
+
+        anno = ddjvu_document_get_anno (djvu_document->d_document, 1);
+        if (anno == miniexp_nil) {
+                ddjvu_miniexp_release (djvu_document->d_document, anno);
+                return info;
+        }
+
+        xmp = ddjvu_anno_get_xmp (anno);
+        if (xmp != NULL) {
+                ev_document_info_set_from_xmp (info, xmp, -1);
+        }
+
+        ddjvu_miniexp_release (djvu_document->d_document, anno);
+        return info;
+}
+
 static void
 djvu_document_finalize (GObject *object)
 {
@@ -566,6 +591,7 @@ djvu_document_class_init (DjvuDocumentClass *klass)
 	ev_document_class->render = djvu_document_render;
 	ev_document_class->get_thumbnail = djvu_document_get_thumbnail;
 	ev_document_class->get_thumbnail_surface = djvu_document_get_thumbnail_surface;
+	ev_document_class->get_info = djvu_document_get_info;
 }
 
 static gchar *
@@ -899,6 +925,71 @@ djvu_document_find_find_text (EvDocumentFind   *document,
 		r->y1 = height - r->y2 * 72.0 / dpi;
 		r->y2 = height - tmp * 72.0 / dpi;
 	}
+
+
+	return matches;
+}
+
+static GList *
+djvu_document_find_find_text_extended (EvDocumentFind *document,
+				       EvPage *page,
+				       const char *text,
+				       EvFindOptions options)
+{
+	DjvuDocument *djvu_document = DJVU_DOCUMENT (document);
+	miniexp_t page_text;
+	gdouble width, height, dpi;
+	GList *matches = NULL, *l;
+	char *search_text = NULL;
+	gboolean case_sensitive = (options & EV_FIND_CASE_SENSITIVE);
+
+	g_return_val_if_fail (text != NULL, NULL);
+
+	while ((page_text = ddjvu_document_get_pagetext (djvu_document->d_document,
+							 page->index,
+							 "char")) == miniexp_dummy)
+		djvu_handle_events (djvu_document, TRUE, NULL);
+
+	if (page_text != miniexp_nil) {
+		DjvuTextPage *tpage = djvu_text_page_new (page_text);
+
+		djvu_text_page_index_text (tpage, case_sensitive);
+		if (tpage->links->len > 0) {
+			if (!case_sensitive) {
+				search_text = g_utf8_casefold (text, -1);
+				djvu_text_page_search (tpage, search_text);
+				g_free (search_text);
+			} else {
+				djvu_text_page_search (tpage, text);
+			}
+			matches = tpage->results;
+		}
+		djvu_text_page_free (tpage);
+		ddjvu_miniexp_release (djvu_document->d_document, page_text);
+	}
+	if (!matches)
+		return NULL;
+
+	document_get_page_size (djvu_document, page->index, &width, &height, &dpi);
+	for (l = matches; l && l->data; l = g_list_next (l)) {
+		EvRectangle *r = (EvRectangle *)l->data;
+		gdouble tmp = r->y1;
+
+		r->x1 *= 72.0 / dpi;
+		r->x2 *= 72.0 / dpi;
+
+		r->y1 = height - r->y2 * 72.0 / dpi;
+		r->y2 = height - tmp * 72.0 / dpi;
+
+		EvFindRectangle *ev_rect = ev_find_rectangle_new ();
+		ev_rect->x1 = r->x1;
+		ev_rect->x2 = r->x2;
+		ev_rect->y1 = r->y1;
+		ev_rect->y2 = r->y2;
+
+		ev_rectangle_free (r);
+		l->data = ev_rect;
+	}
 	
 
 	return matches;
@@ -914,6 +1005,7 @@ static void
 djvu_document_find_iface_init (EvDocumentFindInterface *iface)
 {
         iface->find_text = djvu_document_find_find_text;
+        iface->find_text_extended = djvu_document_find_find_text_extended;
 	iface->get_supported_options = djvu_document_find_get_supported_options;
 }
 
