@@ -47,17 +47,41 @@ static void ev_message_area_get_property (GObject      *object,
 					  guint         prop_id,
 					  GValue       *value,
 					  GParamSpec   *pspec);
+static void ev_message_area_buildable_iface_init (GtkBuildableIface *iface);
 
-G_DEFINE_TYPE_WITH_PRIVATE (EvMessageArea, ev_message_area, GTK_TYPE_INFO_BAR)
+G_DEFINE_TYPE_WITH_CODE (EvMessageArea, ev_message_area, GTK_TYPE_INFO_BAR,
+                         G_ADD_PRIVATE (EvMessageArea)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
+                                                ev_message_area_buildable_iface_init))
+
+#define GET_PRIVATE(o) ev_message_area_get_instance_private (o);
+
+static void
+ev_message_area_constructed (GObject *object)
+{
+	EvMessageArea *ev_message_area = EV_MESSAGE_AREA (object);
+
+	G_OBJECT_CLASS (ev_message_area_parent_class)->constructed (object);
+
+	gtk_widget_show_all (GTK_WIDGET (ev_message_area));
+}
 
 static void
 ev_message_area_class_init (EvMessageAreaClass *class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
+	gobject_class->constructed = ev_message_area_constructed;
 	gobject_class->set_property = ev_message_area_set_property;
 	gobject_class->get_property = ev_message_area_get_property;
 
+	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/evince/ui/message-area.ui");
+	gtk_widget_class_bind_template_child_private (widget_class, EvMessageArea, main_box);
+	gtk_widget_class_bind_template_child_private (widget_class, EvMessageArea, image);
+	gtk_widget_class_bind_template_child_private (widget_class, EvMessageArea, label);
+	gtk_widget_class_bind_template_child_private (widget_class, EvMessageArea, secondary_label);
+
 	g_object_class_install_property (gobject_class,
 					 PROP_TEXT,
 					 g_param_spec_string ("text",
@@ -87,49 +111,7 @@ ev_message_area_class_init (EvMessageAreaClass *class)
 static void
 ev_message_area_init (EvMessageArea *area)
 {
-	GtkWidget *hbox, *vbox;
-	GtkWidget *content_area;
-	EvMessageAreaPrivate *priv;
-
-	priv = ev_message_area_get_instance_private (area);
-
-	priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (priv->main_box), 6);
-
-	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-
-	priv->label = gtk_label_new (NULL);
-	gtk_label_set_use_markup (GTK_LABEL (priv->label), TRUE);
-	gtk_label_set_line_wrap (GTK_LABEL (priv->label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->label), TRUE);
-	g_object_set (G_OBJECT (priv->label), "xalign", 0., "yalign", 0.5, NULL);
-	gtk_widget_set_can_focus (priv->label, TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->label, TRUE, TRUE, 0);
-	gtk_widget_show (priv->label);
-
-	priv->secondary_label = gtk_label_new (NULL);
-	gtk_label_set_use_markup (GTK_LABEL (priv->secondary_label), TRUE);
-	gtk_label_set_line_wrap (GTK_LABEL (priv->secondary_label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->secondary_label), TRUE);
-	g_object_set (G_OBJECT (priv->secondary_label), "xalign", 0., "yalign", 0.5, NULL);
-	gtk_widget_set_can_focus (priv->secondary_label, TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), priv->secondary_label, TRUE, TRUE, 0);
-
-	priv->image = gtk_image_new_from_icon_name (NULL, GTK_ICON_SIZE_DIALOG);
-	g_object_set (G_OBJECT (priv->image), "xalign", 0.5, "yalign", 0., NULL);
-	gtk_box_pack_start (GTK_BOX (hbox), priv->image, FALSE, FALSE, 0);
-	gtk_widget_show (priv->image);
-
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-
-	gtk_box_pack_start (GTK_BOX (priv->main_box), hbox, TRUE, TRUE, 0);
-	gtk_widget_show (hbox);
-
-	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (area));
-	gtk_container_add (GTK_CONTAINER (content_area), priv->main_box);
-	gtk_widget_show (priv->main_box);
+	gtk_widget_init_template (GTK_WIDGET (area));
 }
 
 static void
@@ -140,7 +122,7 @@ ev_message_area_set_image_for_type (EvMessageArea *area,
 	AtkObject   *atk_obj;
 	EvMessageAreaPrivate *priv;
 
-	priv = ev_message_area_get_instance_private (area);
+	priv = GET_PRIVATE (area);
 
 	switch (type) {
 	case GTK_MESSAGE_INFO:
@@ -207,9 +189,7 @@ ev_message_area_get_property (GObject     *object,
 			      GParamSpec  *pspec)
 {
 	EvMessageArea *area = EV_MESSAGE_AREA (object);
-	EvMessageAreaPrivate *priv;
-
-	priv = ev_message_area_get_instance_private (area);
+	EvMessageAreaPrivate *priv = GET_PRIVATE (area);
 
 	switch (prop_id) {
 	case PROP_TEXT:
@@ -227,6 +207,29 @@ ev_message_area_get_property (GObject     *object,
 	}
 }
 
+static GtkBuildableIface *parent_buildable_iface;
+
+static GObject *
+ev_message_area_buildable_get_internal_child (GtkBuildable *buildable,
+                             GtkBuilder   *builder,
+                             const char   *childname)
+{
+        EvMessageArea *area = EV_MESSAGE_AREA (buildable);
+
+        if (g_strcmp0 (childname, "main_box") == 0)
+                return G_OBJECT (_ev_message_area_get_main_box (area));
+
+        return parent_buildable_iface->get_internal_child (buildable, builder, childname);
+}
+
+static void
+ev_message_area_buildable_iface_init (GtkBuildableIface *iface)
+{
+        parent_buildable_iface = g_type_interface_peek_parent (iface);
+
+        iface->get_internal_child = ev_message_area_buildable_get_internal_child;
+}
+
 void
 _ev_message_area_add_buttons_valist (EvMessageArea *area,
 				     const gchar   *first_button_text,
@@ -257,7 +260,7 @@ _ev_message_area_get_main_box (EvMessageArea *area)
 {
 	EvMessageAreaPrivate *priv;
 
-	priv = ev_message_area_get_instance_private (area);
+	priv = GET_PRIVATE (area);
 	return priv->main_box;
 }
 
@@ -295,10 +298,9 @@ ev_message_area_set_image (EvMessageArea *area,
 	GtkWidget *parent;
 	EvMessageAreaPrivate *priv;
 
-	priv = ev_message_area_get_instance_private (area);
-
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
 
+	priv = GET_PRIVATE (area);
 	priv->message_type = GTK_MESSAGE_OTHER;
 
 	parent = gtk_widget_get_parent (priv->image);
@@ -320,7 +322,7 @@ ev_message_area_set_image_from_icon_name (EvMessageArea *area,
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
 	g_return_if_fail (icon_name != NULL);
 
-	priv = ev_message_area_get_instance_private (area);
+	priv = GET_PRIVATE (area);
 
 	gtk_image_set_from_icon_name (GTK_IMAGE (priv->image),
 				      icon_name,
@@ -335,7 +337,7 @@ ev_message_area_set_text (EvMessageArea *area,
 
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
 
-	priv = ev_message_area_get_instance_private (area);
+	priv = GET_PRIVATE (area);
 
 	if (str) {
 		gchar *msg, *escaped;
@@ -360,7 +362,7 @@ ev_message_area_set_secondary_text (EvMessageArea *area,
 
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
 
-	priv = ev_message_area_get_instance_private (area);
+	priv = GET_PRIVATE (area);
 
 	if (str) {
 		gchar *msg;
